import _createClass from "@babel/runtime/helpers/esm/createClass";
import DefaultAdapter from './adapters/default';
import { slugify } from './slugify';

var Rosetta =
/*#__PURE__*/
function () {
  function Rosetta(_temp) {
    var _ref = _temp === void 0 ? {} : _temp,
        _ref$adapter = _ref.adapter,
        adapter = _ref$adapter === void 0 ? new DefaultAdapter() : _ref$adapter;

    this._culture = null;
    this._currency = null;
    this._languages = null;
    this.translator = adapter;
  }

  var _proto = Rosetta.prototype;

  // Translate.
  _proto.t = function t(key, values) {
    return this.translator.translate(key, values);
  } // Format number.
  ;

  _proto.n = function n(number, options) {
    if (options === void 0) {
      options = {};
    }

    if (typeof number !== 'number') {
      throw new Error('i18n.n should receive a number.');
    }

    return typeof Intl !== 'undefined' ? new Intl.NumberFormat(this._culture, options).format(number) : number;
  } // Format currency number.
  ;

  _proto.c = function c(number, minimumFractionDigits) {
    if (minimumFractionDigits === void 0) {
      minimumFractionDigits = 0;
    }

    return this.n(number, {
      style: 'currency',
      currency: this._currency,
      minimumFractionDigits: minimumFractionDigits
    });
  }
  /**
   * Format minor types.
   *
   * @param {String} type The kind of value to be formatted:
   *                        - phone
   * @param {} value The value to be formatted
   * @param {Object} options Specific options for the specified type
   */
  ;

  _proto.f = function f(type, value, options) {
    if (options === void 0) {
      options = {};
    }

    if (typeof type !== 'string') throw new Error('i18n.f should receive a string as a first argument');
    if (typeof value === 'undefined') throw new Error('i18n.f should receive any value as a second argument');

    switch (type) {
      case 'phone':
        {
          var _options = options,
              _options$separator = _options.separator,
              separator = _options$separator === void 0 ? ' ' : _options$separator;
          return value.replace(/ /g, '') // reset all spaces
          .match(/.{1,3}/g) // group by chunks of 3
          .join(separator);
        }
    }

    throw new Error("Invalid type '" + type + "' passed to i18n.f");
  };

  _proto.url = function url(urlPattern, allowQueryParams) {
    var _this = this;

    return urlPattern.split('/').map(function (token) {
      return slugify(_this.t(token), allowQueryParams);
    }).join('/');
  };

  _createClass(Rosetta, [{
    key: "adapter",
    set: function set(adapter) {
      this.translator = adapter;
    },
    get: function get() {
      return this.translator;
    }
  }, {
    key: "culture",
    set: function set(culture) {
      this._culture = culture;
      this.translator.locale = culture.split('-')[0];
      this.translator.translations = this._languages[culture];
    },
    get: function get() {
      return this._culture;
    }
  }, {
    key: "currency",
    set: function set(currency) {
      this._currency = currency;
    },
    get: function get() {
      return this._currency;
    }
  }, {
    key: "locale",
    get: function get() {
      return this.translator.locale;
    }
  }, {
    key: "languages",
    set: function set(languages) {
      this._languages = languages;
    }
  }]);

  return Rosetta;
}();

export { Rosetta as default };